Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1005)

Unified Diff: content/browser/frame_host/render_frame_host_impl.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: add back previews_unspecified Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_impl.h
diff --git a/content/browser/frame_host/render_frame_host_impl.h b/content/browser/frame_host/render_frame_host_impl.h
index 1edf89248c3f3955dbd7ba55128e9961ca15cbd9..10e49d6b5984aee1830fedb5ba74cf32ecce33d1 100644
--- a/content/browser/frame_host/render_frame_host_impl.h
+++ b/content/browser/frame_host/render_frame_host_impl.h
@@ -569,10 +569,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
void SetHasReceivedUserGesture();
- // PlzNavigate: returns the LoFi state of the last successful navigation that
- // made a network request.
- LoFiState last_navigation_lofi_state() const {
- return last_navigation_lofi_state_;
+ // PlzNavigate: returns the Previews state of the last successful navigation
+ // that made a network request.
+ int last_navigation_previews_state() const {
nasko 2016/12/08 22:19:32 PreviewsState
megjablon 2016/12/09 20:35:54 Done.
+ return last_navigation_previews_state_;
}
protected:
@@ -1044,10 +1044,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
// If true, then the RenderFrame has selected text.
bool has_selection_;
// PlzNavigate: The LoFi state of the last navigation. This is used during
// history navigation of subframes to ensure that subframes navigate with the
- // same LoFi status as the top-level frame.
- LoFiState last_navigation_lofi_state_;
+ // same Previews status as the top-level frame.
+ int last_navigation_previews_state_;
nasko 2016/12/08 22:19:32 PreviewsState
megjablon 2016/12/09 20:35:54 Done.
mojo::Binding<mojom::FrameHost> frame_host_binding_;
@@ -1044,10 +1044,10 @@ class CONTENT_EXPORT RenderFrameHostImpl
// If true, then the RenderFrame has selected text.
bool has_selection_;
- // PlzNavigate: The LoFi state of the last navigation. This is used during
+ // PlzNavigate: The Previews state of the last navigation. This is used during
// history navigation of subframes to ensure that subframes navigate with the
mojom::FramePtr frame_;

Powered by Google App Engine
This is Rietveld 408576698